Documentation
¶
Overview ¶
Package twarc provides tools and types to parse a Twitter/X archive.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExtEntities ¶
type ExtEntities struct {
Media []Media `json:"media"`
}
type Link ¶
type Link struct {
DisplayURL string `json:"display_url"`
ExpandedURL string `json:"expanded_url"`
}
Link represents a link in a tweet.
type Media ¶
type Media struct {
ID ID `json:"id"`
Type string `json:"type"`
URL string `json:"url"`
MediaURL string `json:"media_url_https"`
ExpandedURL string `json:"expanded_url"`
DisplayURL string `json:"display_url"`
SourceStatusID ID `json:"source_status_id"`
VideoInfo VideoInfo `json:"video_info"`
}
Media represents a media item in a tweet.
type Mention ¶
type Mention struct {
ID ID `json:"id"`
Name string `json:"name"`
ScreenName string `json:"screen_name"`
Pos Range `json:"indices"`
}
Mention represents a mention of a user in a tweet.
type Tweet ¶
type Tweet struct {
ID ID `json:"id"`
CreatedAt Time `json:"created_at"`
FullText string `json:"full_text"`
InReplyToUserID ID `json:"in_reply_to_user_id"`
InReplyToStatusID ID `json:"in_reply_to_status_id"`
DisplayTextRange Range `json:"display_text_range"`
NumRetweet Int64 `json:"retweet_count"`
NumFavorite Int64 `json:"favorite_count"`
Entities Entities `json:"entities"`
Lang string `json:"lang"`
ExtEntities ExtEntities `json:"extended_entities"`
}
Tweet represents a single tweet.
Click to show internal directories.
Click to hide internal directories.